%==================================================================================
function [P, V, F] = Phase_C_Fit(time,voltage,t1,t2,baseline)
% Estimate the parameters (coefficients) of the nonlinear ODE for Phase C
% time:       time vector of the signal (SCALE IS 'MS', i.e. 0ms, 1ms, 2ms, ...
% voltage:    position data of the probe/needle
% -- time and voltage must be column vectors
% t1:         time of the first crest in the data
% t2:         time of the second crest in the data
% -- from t1 and t2, a rough estimate of the decay rate and period can be computed,
%    whereby all subsequent initial parameters can be computed
% baseline:   guess for the steady-state voltage for Phase C
%==================================================================================
 
    % Reconstructed Voltage
    global V;
    
    % Estimate parameters 
    Mass    = 10; 
    T       = t2-t1;                                 % Period
    Omega   = 2*pi/T;                                % Frequency 
    Delta   = -1/T * log(voltage(t2)/voltage(t1));   % Decay Rate
    Beta    = 2*Mass*Delta;                          % Damping coefficient 
    Alpha   = Mass*(Omega^2 + Delta^2);              % Restoring Force Coefficient
    Shift   = baseline;                              % Steady-state voltage
    P0      = [[Beta 0 0] [Alpha 0 0] Shift];        % Consolidate initial parameters into one vector          
    IC      = [voltage(1)-baseline; 0];              % Initial conditions for ODE 

    %Find Optimal Parameters  
    [P,F] = fminsearch(@Phase_C_Obj, P0, [], time, voltage, IC);   
return    

